@@ -29,7 +29,7 @@
 
 static const gchar *audacious_brief =
  "<big><b>Audacious %s</b></big>\n"
- "Copyright (C) 2005-2011 Audacious Team";
+ "Copyright (C) 2005-2012 Audacious Team";
 
 static const gchar *credit_text[] = {
     N_("Core developers:"),
@@ -75,13 +75,14 @@ static const gchar *credit_text[] = {
     "William Pitcock",
     "Derek Pomery",
     "Jonathan Schleifer",
-    "Andrew O. Shadoura",
+    "Andrew Shadura",
     "Tony Vroon",
     "Yoshiki Yazawa",
     NULL,
 
     N_("Patch authors:"),
     "Chris Arepantis",
+    "Anatoly Arzhnikov",
     "Alexis Ballier",
     "Eric Barch",
     "Carlo Bramini",
@@ -93,6 +94,7 @@ static const gchar *credit_text[] = {
     "Mike Frysinger",
     "Mark Glines",
     "Hans de Goede",
+    "David Guglielmi",
     "Michael Hanselmann",
     "Juho Heikkinen",
     "Joseph Jezak",
