@@ -170,8 +170,12 @@ static void entry_set_tuple_real (Entry * entry, Tuple * tuple)
 {
     /* Hack: We cannot refresh segmented entries (since their info is read from
      * the cue sheet when it is first loaded), so leave them alone. -jlindgren */
-    if (entry->segmented && ! tuple)
+    if (entry->segmented && entry->tuple)
+    {
+        if (tuple)
+            tuple_free (tuple);
         return;
+    }
 
     if (entry->tuple)
         tuple_free (entry->tuple);
@@ -418,8 +422,7 @@ static void queue_update (gint level, gint list, gint at, gint count)
     }
 
     if (! update_source)
-        update_source = g_idle_add_full (G_PRIORITY_HIGH_IDLE, update, NULL,
-         NULL);
+        update_source = g_idle_add_full (G_PRIORITY_HIGH, update, NULL, NULL);
 }
 
 gboolean playlist_update_pending (void)
@@ -544,13 +547,14 @@ static void * scanner (void * data)
         Entry * entry = scan_items[i]->entry;
         gchar * filename = g_strdup (entry->filename);
         PluginHandle * decoder = entry->decoder;
+        gboolean need_tuple = entry->tuple ? FALSE : TRUE;
 
         LEAVE;
 
         if (! decoder)
             decoder = file_find_decoder (filename, FALSE);
 
-        Tuple * tuple = decoder ? file_read_tuple (filename, decoder) : NULL;
+        Tuple * tuple = (need_tuple && decoder) ? file_read_tuple (filename, decoder) : NULL;
 
         ENTER;
 
@@ -566,12 +570,13 @@ static void * scanner (void * data)
         entry->decoder = decoder;
 
         if (tuple)
+        {
             entry_set_tuple (playlist, entry, tuple);
-        else
+            queue_update (PLAYLIST_UPDATE_METADATA, playlist->number, entry->number, 1);
+        }
+        else if (need_tuple)
             entry_set_failed (playlist, entry);
 
-        queue_update (PLAYLIST_UPDATE_METADATA, playlist->number, entry->number, 1);
-
         g_slice_free (ScanItem, scan_items[i]);
         scan_items[i] = NULL;
 
